Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'proctools')
-rw-r--r--proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.properties9
-rw-r--r--proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.xml6
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/META-INF/MANIFEST.MF2
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/plugin.properties3
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/capabilities.exsd12
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/protocols.exsd14
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConnectionProvider.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConstants.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/AbstractNotifier.java8
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/IListener.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/INotifier.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/ITool.java5
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogConnect.java5
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogLogin.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/IToolViewPart.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/Messages.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionConnect.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionDisconnect.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionPause.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRefresh.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRun.java4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/messages.properties4
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/Extensions.java7
-rw-r--r--proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/ProtocolDescriptor.java5
24 files changed, 79 insertions, 49 deletions
diff --git a/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.properties b/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.properties
index 2f5d248f79..90b4cf607f 100644
--- a/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.properties
+++ b/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.properties
@@ -1,5 +1,5 @@
###############################################################################
-# Copyright (c)2009 Motorola Inc and others.
+# Copyright (c) 2009-2010 Motorola Inc and others.
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
@@ -8,22 +8,23 @@
# Contributors:
# Fabio Fantato (Eldorado Research Institute) - initial API and implementation
# Mauren Brenner (Eldorado) - [257585] Update provider name
+# Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
###############################################################################
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8
# "featureName" property - name of the feature
-featureName=TmL: /proc Tools (Incubation)
+featureName=Sequoyah: /proc Tools (Incubation)
# "description" property - description of the feature
-description=TmL /proc Tools
+description=Sequoyah /proc Tools
# "providerName" property - name of the company that provides the feature
providerName=Eclipse.org - DSDP
# "tmUpdateSiteName" property - label for the update site
-tmlUpdateSiteName=Tool for mobile Linux Updates
+sequoyahUpdateSiteName=Sequoyah Updates
# "copyright" property - text of the "Feature Update Copyright"
copyright=\
diff --git a/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.xml b/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.xml
index 2efc5b4bba..f9305cefe8 100644
--- a/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.xml
+++ b/proctools/features/org.eclipse.sequoyah.device.linuxtools.feature/feature.xml
@@ -2,7 +2,7 @@
<feature
id="org.eclipse.sequoyah.device.linuxtools.feature"
label="%featureName"
- version="0.1.0.qualifier"
+ version="0.5.0.qualifier"
provider-name="%providerName"
plugin="org.eclipse.sequoyah.device.linuxtools">
@@ -19,8 +19,8 @@
</license>
<url>
- <update label="%tmlUpdateSiteName" url="http://download.eclipse.org/dsdp/tml/updates/0.3/"/>
- <discovery label="%tmlUpdateSiteName" url="http://download.eclipse.org/dsdp/tml/updates/0.3/"/>
+ <update label="%sequoyahUpdateSiteName" url="http://download.eclipse.org/sequoyah/updates/0.5/"/>
+ <discovery label="%sequoyahUpdateSiteName" url="http://download.eclipse.org/sequoyah/updates/0.5/"/>
</url>
<plugin
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/META-INF/MANIFEST.MF b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/META-INF/MANIFEST.MF
index f91aaf9df0..cc3e1f5d54 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/META-INF/MANIFEST.MF
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/META-INF/MANIFEST.MF
@@ -2,7 +2,7 @@ Manifest-Version: 1.0
Bundle-ManifestVersion: 2
Bundle-Name: %pluginName
Bundle-SymbolicName: org.eclipse.sequoyah.device.linuxtools.base;singleton:=true
-Bundle-Version: 0.1.0.qualifier
+Bundle-Version: 0.5.0.qualifier
Bundle-Vendor: %providerName
Bundle-RequiredExecutionEnvironment: J2SE-1.5
Bundle-ActivationPolicy: lazy
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/plugin.properties b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/plugin.properties
index 0db3ea49cf..1cb53c9eb7 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/plugin.properties
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/plugin.properties
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2008, 2009 Motorola Inc.
+# Copyright (c) 2008-2010 Motorola Inc.
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
@@ -10,6 +10,7 @@
#
# Contributors:
# Mauren Brenner (Eldorado) - [257585] Update provider name
+# Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
################################################################################
# NLS_MESSAGEFORMAT_NONE
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/capabilities.exsd b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/capabilities.exsd
index 7a5e14cd8d..408801ccb8 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/capabilities.exsd
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/capabilities.exsd
@@ -70,5 +70,17 @@
+ <annotation>
+ <appInfo>
+ <meta.section type="copyright"/>
+ </appInfo>
+ <documentation>
+ Copyright (c) 2007-2010 Motorola Inc. All rights reserved.
+ This program and the accompanying materials are made available under the terms
+ of the Eclipse Public License v1.0 which accompanies this distribution, and is
+ available at http://www.eclipse.org/legal/epl-v10.html
+
+ </documentation>
+ </annotation>
</schema>
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/protocols.exsd b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/protocols.exsd
index 369d9809a1..74a9ed074a 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/protocols.exsd
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/schema/protocols.exsd
@@ -94,7 +94,7 @@
</documentation>
<appInfo>
- <meta.attribute kind="identifier" basedOn="org.eclipse.tml.linuxtools.base.capabilities/capability/@id"/>
+ <meta.attribute kind="identifier" basedOn="org.eclipse.sequoyah.device.linuxtools.base.capabilities/capability/@id"/>
</appInfo>
</annotation>
</attribute>
@@ -105,5 +105,17 @@
+ <annotation>
+ <appInfo>
+ <meta.section type="copyright"/>
+ </appInfo>
+ <documentation>
+ Copyright (c) 2007-2010 Motorola Inc. All rights reserved.
+ This program and the accompanying materials are made available under the terms
+ of the Eclipse Public License v1.0 which accompanies this distribution, and is
+ available at http://www.eclipse.org/legal/epl-v10.html
+
+ </documentation>
+ </annotation>
</schema>
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConnectionProvider.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConnectionProvider.java
index e65bd6af02..095b259672 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConnectionProvider.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConnectionProvider.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.network;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConstants.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConstants.java
index 5493c6ffad..e52222805b 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConstants.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/network/IConstants.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.network;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/AbstractNotifier.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/AbstractNotifier.java
index 2c2b326f21..488342c278 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/AbstractNotifier.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/AbstractNotifier.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.tools;
@@ -26,7 +26,7 @@ public class AbstractNotifier implements INotifier{
private ArrayList<IListener> listeners = new ArrayList<IListener>();
/* (non-Javadoc)
- * @see org.eclipse.tml.linuxmemorymapviewer.network.IConnectionProvider#addListener(org.eclipse.tml.linuxmemorymapviewer.network.IListener)
+ * @see org.eclipse.sequoyah.linuxmemorymapviewer.network.IConnectionProvider#addListener(org.eclipse.sequoyah.linuxmemorymapviewer.network.IListener)
*/
public void addListener(IListener listener) {
if (null != listener) {
@@ -42,7 +42,7 @@ public class AbstractNotifier implements INotifier{
}
/* (non-Javadoc)
- * @see org.eclipse.tml.linuxmemorymapviewer.network.IConnectionProvider#notifyListeners(org.eclipse.tml.linuxmemorymapviewer.network.IConnectionConstants.EventCode, java.lang.Object)
+ * @see org.eclipse.sequoyah.linuxmemorymapviewer.network.IConnectionProvider#notifyListeners(org.eclipse.sequoyah.linuxmemorymapviewer.network.IConnectionConstants.EventCode, java.lang.Object)
*/
public void notifyListeners(EventCode event, Object result) {
for (IListener listener:listeners){
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/IListener.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/IListener.java
index 513c1dc502..7bc9ec0fc1 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/IListener.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/IListener.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.tools;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/INotifier.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/INotifier.java
index edeb2280a3..43be0cbe3a 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/INotifier.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/INotifier.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.tools;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/ITool.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/ITool.java
index 245233f2d5..80d18985eb 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/ITool.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/tools/ITool.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,8 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.tools;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogConnect.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogConnect.java
index 30879c8274..09df003f17 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogConnect.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogConnect.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,8 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogLogin.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogLogin.java
index c91a4b59f0..cafa7f0065 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogLogin.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/DialogLogin.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/IToolViewPart.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/IToolViewPart.java
index bc1acb97ce..44d779b3ae 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/IToolViewPart.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/IToolViewPart.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/Messages.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/Messages.java
index 725c6683d3..21b6a54b2f 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/Messages.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/Messages.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionConnect.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionConnect.java
index 963cc74d1e..644ca836ff 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionConnect.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionConnect.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionDisconnect.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionDisconnect.java
index 308ff5dc92..ccd0fcae0e 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionDisconnect.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionDisconnect.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionPause.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionPause.java
index 3e2a031e8a..af62b4ae07 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionPause.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionPause.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRefresh.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRefresh.java
index 15d7822ffa..6ed606734d 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRefresh.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRefresh.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRun.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRun.java
index 28a3e604ef..98e969b5cd 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRun.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/ViewActionRun.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,7 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * {Name} (company) - description of contribution.
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.ui;
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/messages.properties b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/messages.properties
index 494d38abcb..57da3deaea 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/messages.properties
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/ui/messages.properties
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2008 Motorola Inc.
+# Copyright (c) 2008-2010 Motorola Inc.
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
@@ -9,7 +9,7 @@
# Otávio Ferranti (Motorola)
#
# Contributors:
-# {Name} (company) - description of contribution.
+# Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
################################################################################
# NLS_MESSAGEFORMAT_VAR
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/ProtocolDescriptor.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/ProtocolDescriptor.java
index 8476a75dd4..c6561b720b 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/ProtocolDescriptor.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/ProtocolDescriptor.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,8 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
- * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.utilities;

Back to the top
diff --git a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/Extensions.java b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/Extensions.java
index 69104887fb..885799ec34 100644
--- a/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/Extensions.java
+++ b/proctools/plugins/org.eclipse.sequoyah.device.linuxtools.base/src/org/eclipse/sequoyah/device/linuxtools/utilities/Extensions.java
@@ -1,5 +1,5 @@
/********************************************************************************
- * Copyright (c) 2008 Motorola Inc. All rights reserved.
+ * Copyright (c) 2008-2010 Motorola Inc. All rights reserved.
* This program and the accompanying materials are made available under the terms
* of the Eclipse Public License v1.0 which accompanies this distribution, and is
* available at http://www.eclipse.org/legal/epl-v10.html
@@ -8,7 +8,8 @@
* Otavio Ferranti (Motorola)
*
* Contributors:
* Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.utilities;
@@ -26,7 +27,7 @@ import org.eclipse.sequoyah.device.linuxtools.network.IConnectionProvider;
public class Extensions {
static final private String PROTOCOLS_EXTENSION =
- "org.eclipse.tml.linuxtools.base.protocols"; //$NON-NLS-1$
+ "org.eclipse.sequoyah.device.linuxtools.base.protocols"; //$NON-NLS-1$
static final private String CLASS = "class"; //$NON-NLS-1$
static final private String DEFAULT_PORT = "default_port"; //$NON-NLS-1$
@@ -8,7 +8,8 @@
*
* Contributors:
- * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Otavio Ferranti - Eldorado Research Institute - Bug 255255 [tml][proctools] Add extension points
+ * Daniel Pastore (Eldorado) - [289870] Moving and renaming Tml to Sequoyah
********************************************************************************/
package org.eclipse.sequoyah.device.linuxtools.utilities;